@@ -34,11 +34,7 @@
 #include <shellapi.h>
 #include <mstcpip.h>
 
-#ifdef HAVE_VERSIONHELPERS_H
 #include <versionhelpers.h>
-#else
-#include "compat-versionhelpers.h"
-#endif
 
 #include "openvpn-msg.h"
 #include "validate.h"
